# Installation
Open `Terminal` on your computer. 
Then, install `RandomWords` by typing `pip install RandomWords`. 
Finally, clone this repository by typing `git clone git@github.com:aaditisawesome/hangman.git` or by typing `git clone https://github.com/aaditisawesome/hangman.git`

# Opening up the game
Play the game by typing `python hangman.py`
A tkinter window should open on your screen.

Have Fun playing!
# Tips on the game and how to play
1. The computer will choose the word, and you have to guess it

2. There is a timer on the top right corner of the window. When you get the word OR you run out of tries, that timer will end. See how fast you can get it!

3. Instead of pressing submit on your window, you can just press `Enter` on your keyboard!

4. The hangman is hung when you use up nine tries.

5. The `Submit` button automatically becomes `New Game` when the game is over. You can press `Enter` for that also.
